==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/forum/lang/forum_lt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=lt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'tik busimiems straipsniams (jokių veiksmų duomenų bazėje).',
	'bouton_radio_articles_tous' => 'visuose straipsniuose be išimties',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'visimes straipsniams, išskyrus tuos, kuriuos dezaktyvavo forumas.',

	// F
	'form_pet_message_commentaire' => 'Pranešimas, komentaras?',
	'forum' => 'Forumas',
	'forum_acces_refuse' => 'Jūs neturite prieigos į šiuos forumus.',
	'forum_attention_dix_caracteres' => '<b>Dėmesio !</b> Jūsų pranešime turi būti mažiausiai 10 simbolių.',
	'forum_attention_trois_caracteres' => '<b>Dėmesio !</b> Jūsų pavadinime turi būti mažiausiai 3 simboliai.',
	'forum_avez_selectionne' => 'Jūs pasirinkote:',
	'forum_cliquer_retour' => 'Paspauskite <a href=\'@retour_forum@\'>čia</a>, kad tęsti.',
	'forum_forum' => 'forumas',
	'forum_message_definitif' => 'galutinis pranešimas: siųsti į interneto svetainę',
	'forum_message_trop_long' => 'Jūsų pranešimas yra per daug ilgasš Maksimalus dydis yra 20000 simbolių.', # MODIF
	'forum_ne_repondez_pas' => 'Atsakykite į šį pranešimą tik forume šiuo adresu:', # MODIF
	'forum_page_url' => 'Jeigu jūsų pranešimas remesi internete publikuojamu pranešimu arba tinklalapiu teikiančiu daugiau informacijos, jūs galite nurodyti žemiau tinklalapio pavadinimą ir adresą',
	'forum_poste_par' => 'Įdėtas pranešimas @parauteur@ atitinkantis straipsniu « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Kas jūs esate?</b> (pasirinktinai)', # MODIF
	'forum_texte' => 'Jūsų žinutės tekstas',
	'forum_titre' => 'Pavadinimas', # RELIRE
	'forum_url' => 'URL adresas', # RELIRE
	'forum_valider' => 'Patvirtinti šį pasirinkimą',
	'forum_voir_avant' => 'Peržiūrėti pranešimą iki siuntimo', # MODIF
	'forum_votre_email' => 'Jūsų el. pašto adresas',
	'forum_votre_nom' => 'Jūsų vardas', # RELIRE
	'forum_vous_enregistrer' => 'Kad galėtumėte dalyvauti  šiame forume, jūs turite iš anksto užsiregistruoti. Prašome
  nurodyti žemiau jūsų duomenis, kuriuos jūs  esate įvedę. Jeigu jūs nesate užregistruoti, jūs turite',
	'forum_vous_inscrire' => 'jūs įrašyti',

	// I
	'icone_suivi_forums' => 'Peržiūrėti/tvarkyti forumus',
	'icone_supprimer_message' => 'Ištrinti šį pranešimą',
	'icone_valider_message' => 'Patvirtinti šį pranešimą',
	'info_liens_syndiques_3' => 'forumai',
	'info_liens_syndiques_4' => 'yra',
	'info_liens_syndiques_5' => 'forumas',
	'info_liens_syndiques_6' => 'yra',
	'info_liens_syndiques_7' => 'laukia patvirtinimo',

	// O
	'onglet_messages_internes' => 'Vidiniai pranešimai',

	// R
	'repondre_message' => 'Atsakyti į šį pranešimą',

	// T
	'titre_forum' => 'Forumas'
);

?>

==> spip_3.0.22.orig.tar.xz: spip/plugins-dist/forum/lang/forum_lt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=lt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'tik busimiems straipsniams (jokių veiksmų duomenų bazėje).',
	'bouton_radio_articles_tous' => 'visuose straipsniuose be išimties',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'visimes straipsniams, išskyrus tuos, kuriuos dezaktyvavo forumas.',

	// F
	'form_pet_message_commentaire' => 'Pranešimas, komentaras?',
	'forum' => 'Forumas',
	'forum_acces_refuse' => 'Jūs neturite prieigos į šiuos forumus.',
	'forum_attention_dix_caracteres' => '<b>Dėmesio !</b> Jūsų pranešime turi būti mažiausiai 10 simbolių.',
	'forum_attention_trois_caracteres' => '<b>Dėmesio !</b> Jūsų pavadinime turi būti mažiausiai 3 simboliai.',
	'forum_avez_selectionne' => 'Jūs pasirinkote:',
	'forum_cliquer_retour' => 'Paspauskite <a href=\'@retour_forum@\'>čia</a>, kad tęsti.',
	'forum_forum' => 'forumas',
	'forum_message_definitif' => 'galutinis pranešimas: siųsti į interneto svetainę',
	'forum_message_trop_long' => 'Jūsų pranešimas yra per daug ilgasš Maksimalus dydis yra 20000 simbolių.', # MODIF
	'forum_ne_repondez_pas' => 'Atsakykite į šį pranešimą tik forume šiuo adresu:', # MODIF
	'forum_page_url' => 'Jeigu jūsų pranešimas remesi internete publikuojamu pranešimu arba tinklalapiu teikiančiu daugiau informacijos, jūs galite nurodyti žemiau tinklalapio pavadinimą ir adresą',
	'forum_poste_par' => 'Įdėtas pranešimas @parauteur@ atitinkantis straipsniu « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Kas jūs esate?</b> (pasirinktinai)', # MODIF
	'forum_texte' => 'Jūsų pranešimo tekstas:', # MODIF
	'forum_titre' => 'Pavadinimas:', # MODIF
	'forum_url' => 'URL adresas:', # MODIF
	'forum_valider' => 'Patvirtinti šį pasirinkimą',
	'forum_voir_avant' => 'Peržiūrėti pranešimą iki siuntimo', # MODIF
	'forum_votre_email' => 'Jūsų el. pašto adresas:', # MODIF
	'forum_votre_nom' => 'Jūsų vardas (arba pseudonimas) :', # MODIF
	'forum_vous_enregistrer' => 'Kad galėtumėte dalyvauti  šiame forume, jūs turite iš anksto užsiregistruoti. Prašome
  nurodyti žemiau jūsų duomenis, kuriuos jūs  esate įvedę. Jeigu jūs nesate užregistruoti, jūs turite',
	'forum_vous_inscrire' => 'jūs įrašyti',

	// I
	'icone_suivi_forums' => 'Peržiūrėti/tvarkyti forumus',
	'icone_supprimer_message' => 'Ištrinti šį pranešimą',
	'icone_valider_message' => 'Patvirtinti šį pranešimą',
	'info_liens_syndiques_3' => 'forumai',
	'info_liens_syndiques_4' => 'yra',
	'info_liens_syndiques_5' => 'forumas',
	'info_liens_syndiques_6' => 'yra',
	'info_liens_syndiques_7' => 'laukia patvirtinimo',

	// O
	'onglet_messages_internes' => 'Vidiniai pranešimai',

	// R
	'repondre_message' => 'Atsakyti į šį pranešimą',

	// T
	'titre_forum' => 'Forumas'
);

?>
